"""GÉANT IP product type."""

from orchestrator.domain import SubscriptionModel
from orchestrator.types import SubscriptionLifecycle

from gso.products.product_blocks.geant_ip import GeantIPBlock, GeantIPBlockInactive, GeantIPBlockProvisioning


class GeantIPInactive(SubscriptionModel, is_base=True):
    """An inactive GÉANT IP subscription."""

    geant_ip: GeantIPBlockInactive


class GeantIPProvisioning(GeantIPInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING]):
    """A GÉANT IP subscription that's being provisioned."""

    geant_ip: GeantIPBlockProvisioning


class GeantIP(GeantIPProvisioning, lifecycle=[SubscriptionLifecycle.ACTIVE]):
    """An active GÉANT IP subscription."""

    geant_ip: GeantIPBlock


class ImportedGeantIPInactive(SubscriptionModel, is_base=True):
    """An imported, inactive GÉANT IP subscription."""

    geant_ip: GeantIPBlockInactive


class ImportedGeantIP(
    ImportedGeantIPInactive, lifecycle=[SubscriptionLifecycle.PROVISIONING, SubscriptionLifecycle.ACTIVE]
):
    """An imported GÉANT IP subscription."""

    geant_ip: GeantIPBlock
